@@ -169,7 +169,7 @@ CPPCHECK_TOP_HTML = \
 '''<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN" "http://www.w3.org/TR/html4/strict.dtd">
 <html>
     <head>
-        <title>ocit2 0.0.2</title>
+        <title>{{ title }}</title>
         <link href="style.css" rel="stylesheet" type="text/css" />
 		<style type="text/css"></style>
     </head>
@@ -177,7 +177,7 @@ CPPCHECK_TOP_HTML = \
         <div id="page-header">&#160;</div>
         <div id="page">
             <div id="header">
-                <h1>ocit2 0.0.2</h1>
+                <h1>{{ header }}</h1>
             </div>
             <div id="menu">
                 <a href="index.html">Home</a>
@@ -606,7 +606,7 @@ class Component(object):
 	def __init__(self, name, url, severity):
 		self.name = name
 		self.url = '"%s"' % url
-		self.severity = ', '.join(severity)
+		self.severity = ', '.join([s for s in severity if s!=''])
 
 
 class Index(object):
@@ -730,8 +730,10 @@ class CppCheck(object):
 		content = template.render(context)
 		return self.save(url, content, encoding)
 
-	def defects(self, stderr, url):
+	def defects(self, source, stderr, url):
 		defects = []
+		defects.append(Defect(url, '', '', '', '', os.path.basename(source), 0))
+				
 		for error in ElementTree.fromstring(stderr).iter('error'):
 			file = ''
 			line = 0
@@ -769,7 +771,7 @@ class CppCheck(object):
 			stderr = self.bld.cmd_and_log(cmd.split(), quiet=Context.BOTH, output=Context.STDERR)
 			xml = self.save_xml('%s.xml' % name, stderr, cmd)
 			url = xml.replace('.xml', '.html')
-			defects = self.defects(stderr, url)
+			defects = self.defects(source, stderr, url)
 			self.save_html(os.path.basename(url), source, defects)
 			self.report(url, source, defects)
 			severity.extend([defect.severity for defect in defects])
